==> slang-vulkan-sdk-1.4.313.tar.lz: slang-vulkan-sdk-1.4.313/external/slang-rhi/src/core/assert.h <==
#pragma once

namespace rhi {

[[noreturn]] void handleAssert(const char* message, const char* file, int line);

}

#define SLANG_RHI_ASSERT_FAILURE(what)                                                                                 \
    {                                                                                                                  \
        ::rhi::handleAssert(what, __FILE__, __LINE__);                                                                 \
    }

#define SLANG_RHI_ASSERT(x)                                                                                            \
    {                                                                                                                  \
        if (!(x))                                                                                                      \
            SLANG_RHI_ASSERT_FAILURE(#x);                                                                              \
    }

#define SLANG_RHI_UNIMPLEMENTED(what)                                                                                  \
    {                                                                                                                  \
        SLANG_RHI_ASSERT_FAILURE("Not implemented");                                                                   \
    }

#define SLANG_RHI_UNREACHABLE(what)                                                                                    \
    {                                                                                                                  \
        SLANG_RHI_ASSERT_FAILURE("Unreachable");                                                                       \
    }

==> slang-vulkan-sdk-1.4.341.tar.lz: slang-vulkan-sdk-1.4.341/external/slang-rhi/src/core/assert.h <==
#pragma once

namespace rhi {

class ScopedDisableAssert
{
public:
    ScopedDisableAssert();
    ~ScopedDisableAssert();
};

void handleAssert(const char* message, const char* file, int line);

} // namespace rhi

#define SLANG_RHI_DISABLE_ASSERT_SCOPE() ::rhi::ScopedDisableAssert disable_assert__;

#define SLANG_RHI_ASSERT_FAILURE(what)                                                                                 \
    {                                                                                                                  \
        ::rhi::handleAssert(what, __FILE__, __LINE__);                                                                 \
    }

#define SLANG_RHI_ASSERT(x)                                                                                            \
    {                                                                                                                  \
        if (!(x))                                                                                                      \
            SLANG_RHI_ASSERT_FAILURE(#x);                                                                              \
    }

#define SLANG_RHI_UNIMPLEMENTED(what)                                                                                  \
    {                                                                                                                  \
        SLANG_RHI_ASSERT_FAILURE("Not implemented");                                                                   \
    }

#define SLANG_RHI_UNREACHABLE(what)                                                                                    \
    {                                                                                                                  \
        SLANG_RHI_ASSERT_FAILURE("Unreachable");                                                                       \
    }
